@@ -1,10 +1,10 @@
-__version__ = '0.1.2'
+__version__ = '0.1.5'
 __description__ = '接口自动化用例、测试的一站式解决方案。'
 
 import requests
 from apicase.schema import BaseModel
 from apicase.client.router import APIRouter
-from apicase.client.reuquest import APIRequest
+from apicase.client.reuquest import APIRequest, HttpSession
 from apicase.client.reuquest import session
 from apicase.assertion.comparators import assertJSON
 from apicase.common.enumeration import (
